@@ -218,12 +218,13 @@ class SchemaView(object):
         :param imports: include imports closure
         :return: all slots in schema view
         """
-        d = copy(self._get_dict(SLOTS, imports))
+        slots = copy(self._get_dict(SLOTS, imports))
         if attributes:
             for c in self.all_classes().values():
                 for aname, a in c.attributes.items():
-                    d[aname] = a
-        return d
+                    if aname not in slots:
+                        slots[aname] = a
+        return slots
 
 
     @deprecated("Use `all_enums` instead")
@@ -878,8 +879,15 @@ class SchemaView(object):
         :param imports: include imports closure
         :return: dynamic slot constructed by inference
         """
-        slot = self.get_slot(slot_name, imports, attributes=True)
+        slot = self.get_slot(slot_name, imports, attributes=False)
         cls = self.get_class(class_name, imports)
+        # attributes take priority over schema-level slot definitions, IF
+        # the attributes is declared for the class or an ancestor
+        for an in self.class_ancestors(class_name):
+            a = self.get_class(an, imports)
+            if slot_name in a.attributes:
+                slot = a.attributes[slot_name]
+                break
         islot = None
         if slot is not None:
             # case 1: there is an explicit declaration of the slot
@@ -896,14 +904,6 @@ class SchemaView(object):
             #    if getattr(slot, metaslot_name, None):
             #        setattr(islot, metaslot_name, deepcopy(getattr(slot, metaslot_name)))
         else:
-            # case 2: no independent slot definition, declared as an attribute
-            # (can be attribute of the class, or an ancestor)
-            for an in self.class_ancestors(class_name):
-                a = self.get_class(an, imports)
-                if slot_name in a.attributes:
-                    islot = copy(a.attributes[slot_name])
-                    break
-        if islot is None:
             raise Exception(f'No such slot: {slot_name} and no attribute by that name in ancestors of {class_name}')
 
         COMBINE = {
@@ -1204,19 +1204,32 @@ class SchemaView(object):
         dest = self.schema
         for k, v in schema.prefixes.items():
             if k not in dest.prefixes:
-                dest.prefixes[k] = copy(y)
+                dest.prefixes[k] = copy(v)
         for k, v in schema.classes.items():
             if k not in dest.classes:
-                dest.classes[k] = copy(y)
+                dest.classes[k] = copy(v)
         for k, v in schema.slots.items():
             if k not in dest.slots:
-                dest.slots[k] = copy(y)
+                dest.slots[k] = copy(v)
         for k, v in schema.types.items():
             if k not in dest.types:
-                dest.types[k] = copy(y)
+                dest.types[k] = copy(v)
         for k, v in schema.enums.items():
             if k not in dest.types:
-                dest.enums[k] = copy(y)
+                dest.enums[k] = copy(v)
+        self.set_modified()
+
+    def merge_imports(self):
+        """
+        Merges the full imports closure
+
+        :return:
+        """
+        schema = self.schema
+        to_merge = [s2 for s2 in self.all_schema(imports=True) if s2 != schema]
+        for s2 in to_merge:
+            self.merge_schema(s2)
+        schema.imports = []
         self.set_modified()
 
     def copy_schema(self, new_name: str = None) -> SchemaDefinition:
